@@ -4,6 +4,11 @@
 #' @param docxOut String of length one; path for output Word file.
 #' @param debug Boolean of length one; If \code{True} then \code{\link[base]{browser}()} is called at the beginning of the function
 #' @return Path to the rendered Word file if the operation was successfull.
+#'
+#' @import officer
+#' @import dplyr
+#'
+#' @export
 #' @examples
 #' renderInlineCode(
 #'   paste(examplePath(),'templates/template1.docx',sep = ''),
@@ -32,7 +37,7 @@ renderInlineCode <- function(docxIn, docxOut, debug = F) {
   for(i in seq_len(nrow(smm))){
     stylei<-switch(ifelse(is.na(smm$style_name[i]), "a", "b"), a = NULL, b = styles$style_name[styles$style_id==paste0(styles$style_id[styles$style_name==smm$style_name[i]&styles$style_type=="paragraph"],"Char")])
     doc <- officer::cursor_reach(doc, keyword = paste0("\\Q",smm$text[i],"\\E")) %>% officer::body_remove() %>%
-      officer::cursor_backward() %>% officer::slip_in_text(smm$values[i],pos="after", style = stylei)
+      officer::cursor_backward() %>% slip_in_text2(smm$values[i],pos="after", style = stylei)
   }
 
     print(doc, target = docxOut)
